.. highlight:: shell

============
Installation
============


Stable release
--------------

To install Python port of R's Comprehensive Dynamic Time Warp algorithm package, run this command in your terminal:

.. code-block:: console

    $ pip install dtwr

This is the preferred method to install Python port of R's Comprehensive Dynamic Time Warp algorithm package, as it will always install the most recent stable release.

If you don't have `pip`_ installed, this `Python installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/


From sources
------------

The sources for Python port of R's Comprehensive Dynamic Time Warp algorithm package can be downloaded from the `Github repo`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone git://github.com/tonigi/dtwr

Or download the `tarball`_:

.. code-block:: console

    $ curl  -OL https://github.com/tonigi/dtwr/tarball/master

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python setup.py install


.. _Github repo: https://github.com/tonigi/dtwr
.. _tarball: https://github.com/tonigi/dtwr/tarball/master
